GlyphEntry

Struct GlyphEntry 

pub struct GlyphEntry {
    value: u32,
}
GlyphEntry is a port of Gecko’s CompressedGlyph scheme for storing glyph data compactly.

In the common case (reasonable glyph advances, no offsets from the font em-box, and one glyph per character), we pack glyph advance, glyph id, and some flags into a single u32.

In the uncommon case (multiple glyphs per unicode character, large glyph index/advance, or glyph offsets), we create a DetailedGlyphEntry for the glyph and pack its index into the GlyphEntry.

Fields

value: u32

Implementations

Source

impl GlyphEntry

fn new(value: u32) -> GlyphEntry

fn simple(id: u32, advance: Au) -> GlyphEntry

fn complex(detailed_glyph_index: usize) -> GlyphEntry

Source

impl GlyphEntry

fn advance(&self) -> Au

fn id(&self) -> u32

fn char_is_word_separator(&self) -> bool

True if the original character was a word separator. These include spaces (U+0020), non-breaking spaces (U+00A0), and a few other characters non-exhaustively listed in the specification. Other characters may map to the same glyphs, but this function does not take mapping into account.

See https://drafts.csswg.org/css-text/#word-separator.

fn set_char_is_word_separator(&mut self)

fn detailed_glyph_index(&self) -> usize

fn is_simple(&self) -> bool

fn has_flag(&self, flag: u32) -> bool