pub struct ShapedTextSlicer {
current_glyph_offset: usize,
shaped_text: Arc<ShapedText>,
}Expand description
A data structure used to efficiently slice up a ShapedText into ShapedTextSlices.
Fields
current_glyph_offset: usizeshaped_text: Arc<ShapedText>Implementations
Sourceimpl ShapedTextSlicer
impl ShapedTextSlicer
pub fn new(shaped_text: Arc<ShapedText>) -> Self
Sourcepub fn slice_for_character_count(
&mut self,
desired_character_count: usize,
is_whitespace: bool,
ends_with_whitespace: bool,
) -> Arc<ShapedTextSlice>
pub fn slice_for_character_count( &mut self, desired_character_count: usize, is_whitespace: bool, ends_with_whitespace: bool, ) -> Arc<ShapedTextSlice>
Given a desired character count, consume that number of characters worth
of glyphs from the ShapedText of this ShapedTextSlicer. In addition,
tag the resulting ShapedTextSlice with the given whitespace-related
properties.