pub struct TrailingWhiteSpace<Unit> {
pub hangable: Unit,
pub removable: Unit,
}Expand description
A record of the trailing white space at the end of a run of text or glyphs.
See https://drafts.csswg.org/css-text-3/#white-space-phase-2
Fields
hangable: UnitThe part of the run that “hangs”. This comes before the removable parts of the run.
removable: UnitThe part of the run that is removed at the end of a line. This comes after the hangable parts of the run.